@@ -48,16 +48,19 @@ void top_output_header(char* title, Project* project)
     string_free(base_url_a);
     o(      "</head>\n"
             "<body>\n"
+            "<div id=\"header\">\n"
             "<a name=\"top\"></a>\n"
             "<h1 id=\"toptitle\" title=\"Starbug1\">"); h(string_rawstr(project->name)); o(" %s</h1>\n", _("project management"));
 /*             "<h1 id=\"toptitle\" title=\"Starbug1\"><a href=\"http://www.starbug1.com/\"><img src=\"%s/../img/starbug1.jpg\" alt=\"Starbug1\" /></a></h1>\n", cgiScriptName); */
     o(      "<div id=\"projectmenu\">\n"
-            "\t<ul>\n");
+            "\t<ul>\n"
+            "\t\t<li class=\"blank\">&nbsp;</li>\n");
     o(      "\t\t<li><a href=\"%s/../index.%s/%s/\">%s</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("project top"));
     o(      "\t\t<li><a href=\"%s/../admin.%s/%s/\">%s</a></li>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url, _("project management"));
     o(      "\t</ul>\n"
             "</div>\n"
             "<br clear=\"all\" />\n"
+            "</div>\n"
             "<div id=\"main-content\">");
 }
 
@@ -66,18 +69,17 @@ void top_output_footer()
     /* Finish up the page */
     o(      "</div>\n"
             "<div id=\"footer\">\n"
-            "<hr />\n"
-            "<div align=\"right\">\n"
-            "<p>\n"
-            "\t<a href=\"http://validator.w3.org/check?uri=referer\">\n"
-            "\t\t<img src=\"%s/../img/valid-xhtml10.gif\" alt=\"Valid XHTML 1.0 Transitional\" height=\"31\" width=\"88\" />\n"
-            "\t</a>\n"
-            "</p>\n"
-            "<div><address>Powered by cgic &amp; SQLite3.</address></div>\n"
-            "<div><address><a href=\"http://www.starbug1.com/\">Starbug1</a> version: %s. %s.</address></div>\n"
+            "\t<div align=\"right\">\n"
+            "\t<div><address>Powered by cgic &amp; SQLite3.\n"
+            "\t<a href=\"http://www.starbug1.com/\">Starbug1</a> version: %s. %s.</address></div>\n"
+            "\t<p>\n"
+            "\t\t<a href=\"http://validator.w3.org/check?uri=referer\">\n"
+            "\t\t\t<img src=\"%s/../img/valid-xhtml10.gif\" alt=\"Valid XHTML 1.0 Transitional\" height=\"31\" width=\"88\" />\n"
+            "\t\t</a>\n"
+            "\t</p>\n"
+            "\t</div>\n"
             "</div>\n"
-            "</div>\n"
-            "</body>\n</html>\n", cgiScriptName, VERSION, COPYRIGHT);
+            "</body>\n</html>\n", VERSION, COPYRIGHT, cgiScriptName);
 }
 
 int admin_top_main() {
@@ -145,7 +147,9 @@ void top_top_action()
     o(      "\t\t\t\t<td><input type=\"text\" name=\"project.locale\" value=\""); v(string_rawstr(project_a->locale)); o("\" maxlength=\"5\" /></td>\n"
             "\t\t\t</tr>\n");
     o(      "\t\t</table>\n");
-    o(      "\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
+    o(      "\t\t<div class=\"proc-button\">\n");
+    o(      "\t\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
+    o(      "\t\t</div>\n");
     o(      "\t</form>\n");
     o(      "</div>\n");
     project_free(project_a);
@@ -188,7 +192,9 @@ void top_top_action()
     o(      "\t\t<p>%s</p>\n", _("[project settings description1]"));
     o(      "\t\t<p>%s</p>\n", _("[project settings description2]"));
     o(      "\t\t<p>%s</p>\n", _("[project settings description3]"));
-    o(      "\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
+    o(      "\t\t<div class=\"proc-button\">\n");
+    o(      "\t\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("update"));
+    o(      "\t\t</div>\n");
     o(      "\t</form>\n");
     o(      "\t</div>\n");
     o(      "\t<div id=\"project_add\">\n"
@@ -227,7 +233,9 @@ void top_top_action()
     o(      "\t\t\t\t</tr>\n");
     o(      "\t\t\t</table>\n");
     o(      "\t\t\t<p>%s</p>\n", _("[sub project name description]"));
+    o(      "\t\t<div class=\"proc-button\">\n");
     o(      "\t\t\t<input class=\"button\" type=\"submit\" value=\"%s\" />\n", _("add"));
+    o(      "\t\t</div>\n");
     o(      "\t\t</form>\n");
     o(      "\t</div>\n");
     top_output_footer();
